
### Self-assessment of Translation Quality

The objective of this module is to describe a process by which the Church can reliably determine for themselves the quality of a translation. This assessment is intended to suggest some of the most important techniques for checking a translation. It does not describe every conceivable check that could be employed. Ultimately, the Church must make the decisions regarding what checks are used, when they are done, and who does those checks.

#### How to Use the Assessment

This assessment method employs two types of statements. Some are “yes/no” statements, where a negative response indicates a problem that must be resolved. Other sections use an equally-weighted method that provides translation teams and checkers with statements about the translation. Each statement should be scored by the person doing the check (beginning with the translation team) on a scale of 0-2:

**0** - disagree

**1** - agree somewhat

**2** - strongly agree

At the end of the review, the total value of all responses in a section should be added up. If the responses accurately reflect the state of the translation, this value will provide the reviewer with an approximation of the probability that the translated chapter is of excellent quality. This assessment method is designed to be simple and provide the reviewer with an objective way to determine where the work needs improvement. *For example, if the translation scores relatively well in “Accuracy” but quite poorly in “Naturalness” and “Clarity,” then the translation team needs to do more community checking.*

This assessment method is intended to be used for each chapter of translated biblical content. The translation team should do an assessment of each chapter after they finish their other checks. Then the Level 2 checkers should do it again. Then the Level 3 checkers should also assess the translation with this checklist. As more detailed and extensive checking of the chapter is performed by the Church at each level, the points for the chapter should be updated from each of the first four sections (overview, naturalness, clarity, accuracy), allowing the church and community to see how the translation is improving.

#### The Self-Assessment

The process is divided into five parts: the **overview** (information about the translation itself), **naturalness**, **clarity**, **accuracy**, and **Church approval**.

##### 1. Overview

*Circle either “no” or “yes” for each statement below.*

**no | yes** This translation is a meaning-based translation that attempts to communicate the meaning of the original text in ways that are natural, clear, and accurate in the target language.

**no | yes** Those involved in checking the translation are first-language speakers of the target language.

**no | yes** The translation of this chapter is in agreement with the Statement of Faith.

**no | yes** The translation of this chapter has been done in accordance with the Translation Guidelines.

##### 2. Naturalness: “this is *my* language”

*Circle either “0” or “1” or “2” for each statement below.*

This section can be strengthened by doing more community checking. (See [Language Community Check](../language-community-check/01.md))

**0 1 2** Those who speak this language and have heard this chapter agree that it is translated using the correct form of the language.

**0 1 2** Those who speak this language and have heard this chapter agree that the key words used in this chapter are acceptable and correct for this culture.

**0 1 2** The illustrations or stories in this chapter are easy for people who speak this language to understand.

**0 1 2** Those who speak this language and have heard this chapter agree that the sentence structure and order of the text in this chapter is natural and flows correctly.

**0 1 2** The review of the translation of this chapter for naturalness included community members who have not been directly involved in creating the translation of this chapter.

**0 1 2** The review of the translation of this chapter for naturalness included both believers and non-believers, or at least believers who are relatively unfamiliar with the Bible so that they do not know what the text is supposed to say before they hear it.

**0 1 2** The review of the translation of this chapter for naturalness included speakers of the language from many different age groups.

**0 1 2** The review of the translation of this chapter for naturalness included both men and women.

##### 3. Clarity: “the meaning is clear”

*Circle either “0” or “1” or “2” for each statement below.*

This section can be strengthened by doing more community checking. (See [Language Community Check](../language-community-check/01.md))

**0 1 2** This chapter is translated using language that native speakers of the language agree is easy to understand.

**0 1 2** Speakers of this language agree that the translations of names, places, and verb tenses are all correct in this chapter.

**0 1 2** Figures of speech in this chapter make sense for people in this culture.

**0 1 2** Speakers of this language agree that the way this chapter is structured does not distract from the meaning.

**0 1 2** The review of the translation of this chapter for clarity included community members who have not been directly involved in creating the translation of this chapter.

**0 1 2** The review of the translation of this chapter for clarity included both believers and non-believers, or at least believers who are relatively unfamiliar with the Bible so that they do not know what the text is supposed to say before they hear it.

**0 1 2** The review of the translation of this chapter for clarity included speakers of the language from many different age groups.

**0 1 2** The review of the translation of this chapter for clarity included both men and women.

##### 4. Accuracy: “the translation communicates what the original source text communicated”

*Circle either “0” or “1” or “2” for each statement below.*

This section can be strengthened by doing more accuracy checking. (See [Accuracy Check](../accuracy-check/01.md))

**0 1 2** A complete list of all the important words in the source text for this chapter has been used to help ensure all terms are present in the translation.

**0 1 2** All the important words are translated correctly in this chapter.

**0 1 2** All the important words are translated consistently in this chapter, as well as in other places where the important words appear.

**0 1 2** For the entire chapter, exegetical resources and translation helps have been used to identify and resolve potential translation challenges, including the unfoldingWord® Translation Notes and unfoldingWord® Translation Words.

**0 1 2** Historical details in the source text (like names, places, and events) have been preserved in the translation.

**0 1 2** The meaning of each figure of speech in the translated chapter has been compared and aligned to the intent of the original.

**0 1 2** The translation has been tested with first-language speakers of the target language who were not involved in creating the translation, and they agree that the translation accurately communicates the intended meaning of the source text.

**0 1 2** The translation of this chapter has been compared against at least two source texts.

**0 1 2** All questions or disagreements about any of the meaning in this chapter have been resolved.

**0 1 2** The translation of this chapter has been compared against the original texts (Hebrew, Greek, Aramaic) to check for correct definitions of words and for intent of the original texts.

##### 5. Church approval: “the naturalness, clarity, and accuracy of the translation is approved by the Church that speaks that language”

*Circle either “0” or “1” or “2” for each statement below.*

**no | yes** Church leaders who have checked this translation are first-language speakers of the target language, and include someone who understands well one of the languages in which the source text is available.

**no | yes** People from the language community––both men and women, old and young––have reviewed the translation of this chapter and agree that it is natural and clear. 

**no | yes** Church leaders from at least two different church networks have reviewed the translation of this chapter and agree that it is accurate. 

**no | yes** The leadership (or their delegates) of at least two different church networks have reviewed the translation of this chapter and endorse it as a faithful translation of this chapter of the Bible in this language. 
