

### Steps for Validation Checking

These are steps for the Church Network Delegates to follow when doing Validation Checking. These steps assume that the checker has direct access to the translator or translation team, and can ask questions face-to-face as the checker and the translation team review the translation together. If this is not possible, then the checker should write down the questions for the translation team to review. This could be done using the comment feature of translationCore (preferably), or in the margins of a printed translation draft, or even in a spreadsheet.

#### Before Checking

1. Find out ahead of time which set of stories or which Bible passage you will be checking.
1. Read the passage in several versions in any languages you understand, including the original languages, if possible.
1. Read the passage in the ULT and UST, and read the unfoldingWord® Translation Notes and unfoldingWord® Translation Words.
1. Make note of any parts that you think might be difficult to translate.
1. Research these passages in commentaries and other translation helps, making notes about what you discover.

#### While Checking

1. **Align the passage**. Use the Aligning Tool in translationCore to align the passage with the original language. As a result of the aligning process, you will have questions about parts of the translation. Make note of these with the comment feature in translationCore so that you can ask the translation team about them when you meet, or so that the translation team can see and discuss them before you meet. For instructions about the alignment tool, go to [Alignment Tool](../alignment-tool/01.md). 
1. **Ask Questions**. When you are with the translation team and you want to address something that you think might be a problem in the translation, do not make a statement to the translator that there is a problem in the translation. If you do not speak the target language, then you do not know if there is a problem or not. You only think that there might be a problem. Even if you do speak the target language, it is more polite to ask a question than to make a statement that something is wrong. You could ask something like, “What would you think about saying it this way?” and then suggest an alternative way to translate it. Then together you can discuss the different translation ideas, and you can give reasons why you think one translation alternative might be better than another. Then, after considering the alternatives, the translator or translation team must decide which way is best. For topics to ask questions about while checking a Bible translation, see [Types of Things to Check](../vol2-things-to-check/01.md). 
1. **Explore the target language and culture**.  The questions that you ask will be to discover what the phrase means in the target language. The best questions are the ones that help the translator to think about what the phrase means and how it is used. Useful questions are, “In what situations is this phrase used in your language?” or “Who usually says things like this, and why do they say it?” It is also useful to help the translator to think about what a person from his village would say if in the same situation as the person in the Bible.
1. **Teach the translator**. After you explore the meaning of a phrase in the target language and culture, you can tell the translator what the phrase means in the source language and culture. Then together you can decide if the phrase in the translation or the phrase he has just thought of has that same meaning or not.

#### Checking the Translation Directly

If you speak the target language, then you can read or hear the translation and ask the translation team about it directly.

#### Using a Written Back Translation

If you do not speak the target language, then you will not be able to do the alignment. But you may be a Bible scholar who speaks the Gateway Language and you can help the translation team to improve their translation. In that case, you will need to work from a back translation in the Gateway Language. This can be written separately from the translation, or it can be written as an interlinear––that is, with a line of back translation written under each line of the translation. It is easier to compare the translation to the back translation when they are written as an interlinear, and it is easier to read a back translation that is written separately. Each method has its own strength. The person who makes the back translation should be someone who was not involved in making the translation. See [Back Translation](../vol2-backtranslation/01.md) for more details.

1. If possible, review the back translation in written form before meeting with the translator or translation team face-to-face. This will give you time to think about the passage and to do further research on questions that arise because of what the back translation says. It will also save a lot of time when you meet with the translation team, because there will be a lot of text that you do not need to talk about because you read it in the back translation and it did not have problems. When you meet together, you will be much more productive because you can spend all of your time on the problem areas.
1. As you work through the back translation, make notes of questions that you want to ask the translator, either for clarification or to help the translator think about possible problems with the translation.
1. Ask the translator for a copy of the translation (if it is not interlinear), so that you can compare the translation with the back translation and make note of the connectors that the target language uses and other features that might not be visible in the back translation. Looking at the translation can also help to identify places where the back translation might not accurately represent the translation. For example, the same word that is repeated multiple times in the translation might appear as several different words in the back translation. In this case, it is good to ask the translator why the back translation is different, and if it needs to be corrected.
1. If you cannot review the back translation before meeting with the translator, then work through it with the translator, discussing questions and problems as you work together. Often, as the back translation is compared to the translation, the translator will also discover problems with the translation.

#### Using an Oral Back Translation

If there is no written back translation, then have someone who knows the target language and also a language that you understand make an oral back translation for you. This should be a person who was not involved in making the translation. As you listen to the oral back translation, make notes of words or phrases that seem to communicate the wrong meaning or that present other problems. The person should translate the passage in short segments, pausing in between each segment so that you can ask your questions after you hear each segment.

#### After Checking

Some questions will need to be set aside for later, after the checking session. Be sure to plan a time to meet again to discuss the answers to these questions. These will be:

1. Questions that you or someone else will need to research, usually something about the biblical text that you will need to find out. These might include researching the exact meanings of biblical words or phrases, or the relationship between biblical people or the nature of biblical places.
1. Questions to ask other speakers of the target language. These kinds of questions would be asked to make sure that certain phrases are communicating correctly, or to research the cultural background of certain terms in the target language. These are questions that the translation team may need to ask of people when they return to their community.

### Key Words

Make sure that the translation team is keeping a [list of the Key Words](../../translate/translate-key-terms/01.md) (important terms) from the Bible passages that they are translating, along with the term in the target language that they have decided to use for each of these important terms. You and the translation team will probably need to add to this list and modify the terms from the target language as you progress through the translation of the Bible. Use the list of Key Words to alert you when there are Key Words in the passage that you are translating. Whenever there is a Key Word in the Bible, make sure that the translation uses the term or phrase that has been chosen for that Key Word, and also make sure that it makes sense each time. If it does not make sense, then you will need to discuss why it makes sense in some places but not in others. Then you may need to modify or change the chosen term, or decide to use more than one term in the target language to fit different ways that the Key Word is used. One useful way to do this is to keep track of each important term on a spreadsheet, with columns for the source language term, the target language term, alternative terms and the Bible passages where you are using each term. We hope that this feature will be in future versions of translationStudio.

When you have finished Validation Checking for a Bible book, answer the questions at: [Questions for Validation Checking](../level3-questions/01.md).