

### Description

The term "biblical imagery" refers in a general way to any kind of language in which an image is paired with an idea such that the image represents the idea. This general definition is applied most directly to [metaphors](../figs-metaphor) but can also includes [similes](../figs-simile), [metonymies](../figs-metonymy), and cultural models. 

We have included several modules about biblical imagery in order to tell about the various patterns of imagery found in the Bible. The patterns of pairings found in the Bible are often unique to the Hebrew and Greek languages. It is useful to recognize these patterns because they repeatedly present translators with the same problems regarding how to translate them. Once translators think through how they will handle these translation challenges, they will be ready to meet them anywhere they see the same patterns. See [Biblical Imagery - Common Patterns](../bita-part1/01.md) for links to pages showing common patterns of pairings between ideas in similes and metaphors.

### Common Types of Biblical Imagery

A **simile** is an explicit figure of speech that compares two items using one of the specific terms "like", "as", or "than".

A **metonymy** is an implicit figure of speech that refers to an item (either physical or abstract) not by its own name, but by the name of something closely related to it. See [Biblical Imagery - Common Metonymies](../bita-part2/01.md) for a list of some common metonymies in the Bible.

A **metaphor** is a figure of speech which uses a physical image to refer to an abstract idea, either explicitly or implicitly.  In our translation helps, we distinguish between three different types of metaphors: [simple metaphors](../figs-simetaphor), [extended metaphors](../figs-exmetaphor), and [complex metaphors](../figs-cometaphor).  

In a metaphor, the **Image** is the physical term (object, event, action, etc.) that is used to refer to an abstract term (idea, concept, action, etc.).

In a metaphor, the **Idea** is the abstract term (concept, action, etc.) which is referred to by the physical term (object, event, action, etc.). Often, the Idea of a metaphor is not explicitly stated in the Bible, but only implied from the context.

A **simple metaphor** is an explicit metaphor in which a single physical image is used to refer to a single abstract idea. For example, when Jesus said "I am the light of the world" (John 8:12 ULT), he was using the Image of "light" to refer to an abstract Idea about himself. NOTE: as with many simple metaphors in the Bible, the Image is explicitly stated, but the Idea is implied from the context.

An **extended metaphor** is an explicit metaphor that uses multiple images and multiple ideas at the same time. For example, in Psalm 23 the psalmist writes "Yahweh is my shepherd" and then goes on to describe multiple physical aspects of the relationship between sheep and a shepherd as well as multiple abstract ideas concerning the relationship between himself and Yahweh.

A **complex metaphor** is an implicit metaphor that uses multiple images and multiple ideas at the same time.  *Complex metaphors are very similar to extended metaphors, except that they are implied by the text rather than explicitly stated.  Because of this, complex metaphors can be very difficult to identify in the Bible.* For example, in Ephesians 6:10-20 the apostle Paul describes how a Christian should prepare to resist temptation by comparing abstract ideas to pieces of armor worn by a soldier. The term "full armor of God" is not a combination of several simple metaphors (where the belt represents truth, the helmet represents salvation, etc.). Rather, the unstated complex metaphor PREPARATION IS GETTING DRESSED underlies the entire description as a whole. The apostle Paul was using the physical Image of a soldier putting on his armor (that is, "GETTING DRESSED") to refer to the abstract Idea (that is, "PREPARATION") of a Christian preparing himself to resist temptation.

In our translation helps, we use the term **cultural model** to refer to either an extended metaphor or a complex metaphor that is widely used within a specific culture which may or may not be used within a different culture. See [Biblical Imagery - Cultural Models](../bita-part3/01.md) for a list of some cultural models found in the Bible.


### Cultural Models

Cultural models are complex metaphors that people use to help them imagine and talk about various aspects of life and behavior. For example, Americans often think of many things, including marriage and friendship, as if they were machines. Americans might say, “His marriage is breaking down,” or “Their friendship is going full speed ahead.” Often, cultural models that are used in the Bible are not explicitly stated but must be learned by reading large amounts of text and looking for images and metaphors that are repeated in many different contexts.

For example, both the Old Testament and New Testament describe God as if he were a shepherd and his people were sheep. This is a cultural model that is used frequently in the Bible, and it appears as an extended metaphor in Psalm 23. In the culture of ancient Israel, GOD IS MODELED AS A SHEPHERD.

> <u>Yahweh is my shepherd</u>; I will lack nothing. (Psalm 23:1 ULT) 

> He led his own people out <u>like sheep</u> and guided them through the wilderness <u>like a flock</u>. (Psalm 78:52 ULT)

> <u>I am the good shepherd</u>.  The good shepherd lays down his life for the sheep. (John 10:11 ULT)

> Then when <u>the Chief Shepherd</u> is revealed, you will receive an unfading crown of glory. (1 Peter 5:4 ULT)

Another cultural model is found in Psalm 24, where the psalmist describes God as if he were a mighty and glorious king coming into a city.  In the culture of ancient Israel, GOD IS MODELED AS A KING. 

> Lift up your heads, you gates; be lifted up, everlasting doors, so that the King of glory may come in! Who is this King of glory? Yahweh, strong and mighty; Yahweh, mighty in battle. (Psalm 24:7-8 ULT)

> Someone who breaks open their way for them will go ahead of them. They break through the gate and go out; <u>their king</u> will pass on before them. <u>Yahweh</u> will be at their head. (Micah 2:8 ULT)

> Out of his mouth goes a sharp sword, so that with it he might strike the nations, and he will shepherd them with an iron rod. He tramples in the winepress of the fury of the wrath of <u>God Almighty</u>. He has a name written on his robe and on his thigh: “<u>King of kings and Lord of lords</u>." (Revelation 19:15-16 ULT)

This cultural model was very common in ancient Near Eastern cultures, and the ancient Israelites who read the Bible would have understood it easily because their nation was ruled by a king. However, many modern nations are not ruled by kings, so this specific cultural model is not as easily understood in many modern cultures.


