## Time Relationship

Some connectors establish time relationships between two phrases, clauses, sentences, of chunks of text.

### Background Clause

#### Definition

A background clause is one that describes something that is ongoing, and then another clause indicates an event that begins to happen during that time. These events are also simultaneous events, but they have the further relationship of background event and main event, because the event that is already happening serves as the background for the other event, which is the one that is in focus. The background event simply provides the time frame or other context for the main event or events. 

#### Reason this is a translation issue

Languages indicate a shift in time in different ways. You (the translator) need to understand how these shifts in time are indicated in the original languages in order to communicate them clearly in your own language. Background clauses often indicate a time that began long before the event that is in focus. Translators need to understand how both the source language and the target language communicate background events. Some English words that indicate background events are "now", "when", "while", and "during". Those words can also indicate simultaneous events. To tell the difference, ask yourself if all of the events seem to be equal in importance and started at about the same time. If so, they are probably simultaneous events. But if an event(s) is ongoing and another event(s) just started, then the ongoing event(s) is probably background to the other event(s). Some common phrases that indicate background events are "in those days" and "at that time".

#### Examples from OBS and the Bible

> <u>When</u> Solomon was old, he also worshiped their gods. (OBS Story 18 Frame 3)

Solomon began to worship foreign gods at a time when he was old. Being old is the background event. Worshipping other gods is the main event. 

> <u>Now</u> his parents went <u>every year</u> to Jerusalem for the Festival of the Passover. When he was twelve years old, they again went up at the customary time for the feast.  (Luke 2:41-42 ULT)

The first event––going to Jerusalem––is ongoing and started long ago. We know this because of the words “every year.” Going to Jerusalem is the background event. Then an event begins that started during the time “when he was twelve years old.” So the main event is the specific time Jesus and his family traveled to Jerualem for the Passover festival *when he was twelve years old.*

> Now it came about that <u>while</u> they were there, the time came for the birth of her baby. (Luke 2:6 ULT)

Being in Bethlehem is the background event. The birth of the baby is the main event.

> …<u>while</u> Pontius Pilate was governor of Judea, and Herod was tetrarch of Galilee, and his brother Philip was tetrarch of the region of Ituraea and Trachonitis, and Lysanias was tetrarch of Abilene, <u>during</u> the high priesthood of Annas and Caiaphas—the word of God came to John son of Zechariah in the wilderness. (Luke 3:1-2 ULT)

This example begins with five background clauses (marked by commas), signalled as background by the words “while” and “during.” Then the main event happens: "the word of God came to John".

#### Translation Strategies

If the way that the Background Clauses are marked is also clear in your language, then translate the Background Clauses as they are.

1. If the connecting word does not make it clear that what follows is a Background Clause, use a connecting word that communicates this more clearly.
1. If your language marks Background Clauses in a different way than using connecting words (such as by using different verb forms), then use that way.

#### Examples of Translation Strategies Applied

> …<u>while</u> Pontius Pilate was governor of Judea, and Herod was tetrarch of Galilee, and his brother Philip was tetrarch of the region of Ituraea and Trachonitis, and Lysanias was tetrarch of Abilene, <u>during</u> the high priesthood of Annas and Caiaphas—the word of God came to John son of Zechariah in the wilderness. (Luke 3:1-2 ULT)

(1) If the connecting word does not make it clear that what follows is a Background Clause, use a connecting word that communicates this more clearly.

> …<u>It happened during the time that</u> Pontius Pilate was governor of Judea, <u>and during the time that</u> Herod was tetrarch of Galilee, <u>and during the time that</u> his brother Philip was tetrarch of the region of Ituraea and Trachonitis, <u>and during the time that</u> Lysanias was tetrarch of Abilene, <u>and also during the time that</u> Annas and Caiaphas were high priests—<u>that</u> the word of God came to John son of Zechariah in the wilderness. 

(2) If your language marks Background Clauses in a different way than using connecting words, such as with different verb forms, then use that way.

> …Pontius Pilate <u>was governing</u> Judea, and Herod <u>was ruling over</u> Galilee, and his brother Philip <u>was ruling over</u> the region of Ituraea and Trachonitis, and Lysanias <u>was ruling over</u> Abilene, and Annas and Caiaphas <u>were being</u> high priests—the word of God <u>came</u> to John son of Zechariah in the wilderness. 

#### Example of differences in Time Relationship Connecting Words:

|                          |                                              |
| ------------------------ | -------------------------------------------- |
|Background setting        |The word of Yahweh was rare **in those days**;|
|Background repeated	   |   there was no vision breaking through.      | 
|Introduction of main event|**It happened at that time**,  |
|Background		           |**when** Eli was lying down in his place  |
|Simultaneous background   |**and** his eyes had begun to grow dim so that he could not see well,|
|Simultaneous background   |**and** the lamp of God had not yet gone out,  |
|Simultaneous background   |**and** Samuel was lying down to sleep in the temple of Yahweh,|
|  Simultaneous background |     where the ark of God was.  |
|Main event		           |**Yahweh called to Samuel**,  |
|Sequential event		   |who said, “here I am." (1 Sam 3:1-4 ULT) |

In the above example, the first two lines talk about a condition that was going on for a long time. This is the general, long-term background. We know this from the phrase "in those days." Then there are several lines of short-term background. The first one is introduced by "when," and then three more are connected to the first one by "and." The background clause introduced by "where" explains a little more about the background clause before it. Then the main event happens, followed by more events. Translators will need to think about the best way to show these relationships in their language. 
