
As a translator, you can best use the ULT and UST if you remember the following differences between the ULT and UST, and if you learn how the target language can best deal with the issues that these differences represent.

### Order of Ideas

The ULT tries to present ideas **in the same order** as they appear in the source text.

The UST tries to present ideas in an order that is more natural in English, or that follows the order of logic or the order of sequence in time.

When you translate, you should put ideas into an order that is natural in the target language. (See [Order of Events](../figs-events/01.md).)

> <sup> 1</sup>  Paul, a servant of Jesus Christ, called to be an apostle, and set apart for the gospel of God…<sup> 7</sup>  This letter is to all who are in Rome, the beloved of God. (Romans 1:1,7 ULT) 

> <sup> 1</sup>  I, Paul, who serve Christ Jesus, am writing this letter to all of you believers in the city of Rome. (Romans 1:1 UST) 

The ULT shows Paul’s style of beginning his letters. He does not say who his audience is until verse 7. However, the UST follows a style that is much more natural in English and many other languages today.

### Implied Information

The ULT often presents ideas that **imply** or **assume** other ideas that are important for the reader to understand.

The UST often makes those other ideas explicit. The UST does this in order to remind you that you should perhaps do the same in your translation if you think that your audience will need to know this information in order to understand the text.

When you translate, you should decide which of these implied ideas would be understood by your audience without being included. If your audience understands these ideas without including them in the text, then you do not need to make those ideas explicit. Remember also that you might even offend your audience if you needlessly present implied ideas that they would understand anyway. (See [Assumed Knowledge and Implicit Information](../figs-explicit/01.md).)

> And Jesus said to Simon, “Do not be afraid, because <u>from now on you will catch men</u>.” (Luke 5:10 ULT)

> But Jesus said to Simon, “Do not be afraid! Until now you gathered in fish, but from now on you will gather in people to become my disciples.” (Luke 5:10 UST) 

Here the UST reminds the reader that Simon was a fisherman by trade. It also makes clear the similarity that Jesus was drawing between Simon’s previous work and his future work. In addition, the UST makes it clear why Jesus wanted Simon to “catch men” (ULT), that is, to lead them “to become my disciples” (UST).

> When he saw Jesus, he <u>fell on his face</u> and begged him, saying, “Lord, if you are willing, you can <u>make me clean</u>.” (Luke 5:12 ULT)

> When he saw Jesus, he <u>bowed down to the ground</u> in front of him and pleaded with him, “Lord, <u>please heal me</u>, because you are able to heal me if you are willing!” (Luke 5:12 UST) 

Here the UST makes it clear that the man who had leprosy did not fall to the ground by accident. Instead, he deliberately bowed down to the ground. Also, the UST makes it clear that he is asking Jesus to heal him. In the ULT, he only implies this request.

### Symbolic Actions

**Definition** - A symbolic action is something that someone does in order to express a certain idea.

The ULT often simply presents the symbolic action with no explanation of what it means. The UST often presents the meaning expressed by the symbolic action as well.

When you translate, you should decide whether your audience will correctly understand a symbolic action. If your audience will not understand, then you should do as the UST does. (See [Symbolic Action](../translate-symaction/01.md).)

> The high priest <u>tore his</u> garments (Mark 14:63 ULT)

> In response to Jesus’ words, the high priest <u>was so shocked</u> that he tore his outer garment. (Mark 14:63 UST) 

Here the UST makes it clear that it was not by accident that the high priest tore his garment. It also makes clear that it was probably only his outer garment that he tore, and that he did so because he wanted to show that he was sad or angry or both.

Because the high priest actually tore his garment, the UST must, of course, say that he did. However, if a symbolic action never actually took place, you do not have to state that action. Here is such an example:

> Present that to your governor; will he accept you or will he <u>lift up your face</u>?” (Malachi 1:8 ULT)

> You would not dare to offer such gifts to your own governor! You know that he would not take them. You know that he would be <u>displeased with you and would not welcome you</u>! (Malachi 1:8 UST)  

Here the symbolic action “lift up someone’s face”, represented in this way in the ULT, is presented only as its meaning in the UST: “he would be displeased with you and would not welcome you”. It can be presented in this way because Malachi is not referring to an actual event that took place. He is only referring to the idea represented by that event.

### Passive Verb Forms

Both Biblical Hebrew and Greek often use passive verb forms, while many other languages do not have that possibility. The ULT tries to use passive verb forms when the original languages use them. However, the UST usually does not use these passive verb forms. As a result, the UST **restructures** many phrases.

When you translate, you must decide whether the target language can present events or states using a passive expression, as in the following examples. If you cannot use a passive verb form in a particular context, then you may find in the UST one possible way to restructure the phrase. (See [Active or Passive](../figs-activepassive/01.md).)

### Examples from the Bible

> For <u>he was amazed</u>, and all who were with him, at the catch of fish which they had taken. (Luke 5:9 ULT)

> He said this because <u>he marveled</u> at the huge number of fish that they had caught. All the men who were with him also marveled. (Luke 5:9 UST) 

Here the UST uses a verb in the active voice “he marveled” instead of the ULT’s verb in the passive voice “was amazed.”

> Large crowds of people came together to hear him teach and to be healed of their sicknesses. (Luke 5:15 ULT)

> The result was that large crowds came to Jesus to hear him teach and <u>to have him heal them from their sicknesses</u>. (Luke 5:15 UST) 

Here the UST avoids the ULT’s passive verb form “to be healed”. It does this by restructuring the phrase. It says who the healer is: “to have him [Jesus] heal them”.

### Metaphors and Other Figures of Speech

**Definition** - The ULT tries to represent the figures of speech found in the biblical texts as closely as possible.

The UST often presents the meaning of these ideas in other ways.

When you translate, you will need to decide whether the target language readers will understand a figure of speech with little effort, with some effort, or not at all. If they must make a great effort to understand, or if they do not understand at all, you will need to present the essential meaning of the figure of speech using other words.

> He has <u>made you rich in every way</u>, in all speech and with all knowledge. (1 Corinthians 1:5 ULT)

> Christ has <u>given you so many things</u>. He helped you to speak his truth and to know God. (1 Corinthians 1:5 UST) 

Paul uses a metaphor of material wealth, expressed in the word “rich.” Even though he immediately explains what he means––“in all speech and with all knowledge”––some readers might not understand. The UST presents the idea in a different way, without using the metaphor of material wealth. (See [Metaphor](../figs-metaphor/01.md).)

> I send you out <u>as sheep in the midst of wolves</u>, (Matthew 10:16 ULT)

> When I send you out, you will be <u>as defenseless as sheep, among people who are as dangerous as wolves</u>. (Matthew 10:16 UST) 

Jesus uses a simile that compares his apostles going to others as sheep going out among wolves. Some readers might not understand how the apostles would be like sheep while the other people would be like wolves. The UST clarifies that the apostles would be defenseless, and that their enemies would be dangerous. (See [Simile](../figs-simile/01.md).)

> You are separated from Christ, all <u>you who are “justified” by the law</u>. You have fallen away from grace. (Galatians 5:4 ULT)

> <u>If you expect God to declare you good in his sight because you try to keep the law</u>, you have separated yourself from Christ; God will no longer act kindly toward you. (Galatians 5:4 UST) 

Paul uses irony when he refers to them as being justified by the law. He had already taught them that no one can be justified by the law. The ULT uses quote marks around “justified” to show that Paul did not really believe that they were justified by the law. The UST translates the same idea by making it clear that it was what the other people believed. (See [Irony](../figs-irony/01.md).)

### Abstract Expressions

The ULT often uses abstract nouns, adjectives, and other parts of speech, because it tries to closely resemble the biblical texts.
The UST tries not to use such abstract expressions, because many languages do not use abstract expressions.

When you translate, you will have to decide how the target language prefers to present these ideas. (See [Abstract Nouns](../figs-abstractnouns/01.md).)

> He has made you rich in every way, in <u>all speech</u> and with <u>all knowledge</u>. (1 Corinthians 1:5 ULT)

> Christ has given you so many things. He <u>helped you to speak his truth</u> and <u>to know God</u>. (1 Corinthians 1:5 UST) 

Here the ULT expressions “all speech” and “all knowledge” are abstract noun expressions. One problem with them is that readers might not know who is supposed to do the speaking and what they are to speak, or who is doing the knowing and what it is that they know. The UST answers these questions.

### Conclusion

In summary, the ULT will help you translate because it can help you understand to a great degree what form the original biblical texts have. The UST can help you translate because it can help make the ULT text’s meaning clear, and also because it can give you various possible ways to make the ideas in the biblical text clear in your own translation and cultural setting.
